@@ -19,6 +19,10 @@ class VariableKeyError(QuietException):
     """Raise this exception when a variable key does not have a value."""
 
 
+class MissingAttributeError(QuietException):
+    """Raise this exception when a rule is missing attributes or evaluate()."""
+
+
 # No unit tests for this, due to Python mechanics.
 # https://stackoverflow.com/a/46351418
 def quiet_exception_hook(kind, message, traceback):
